==> qt-creator-2.6.2-src.tar.gz: qt-creator-2.6.2-src/share/qtcreator/qml/qmlpuppet/qml2puppet/instances/qt5informationnodeinstanceserver.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef QMLDESIGNER_QT5INFORMATIONNODEINSTANCESERVER_H
#define QMLDESIGNER_QT5INFORMATIONNODEINSTANCESERVER_H

#include "qt5nodeinstanceserver.h"
#include "tokencommand.h"

namespace QmlDesigner {

class Qt5InformationNodeInstanceServer : public Qt5NodeInstanceServer
{
    Q_OBJECT
public:
    explicit Qt5InformationNodeInstanceServer(NodeInstanceClientInterface *nodeInstanceClient);

    void reparentInstances(const ReparentInstancesCommand &command);
    void clearScene(const ClearSceneCommand &command);
    void createScene(const CreateSceneCommand &command);
    void completeComponent(const CompleteComponentCommand &command);
    void token(const TokenCommand &command);

protected:
    void collectItemChangesAndSendChangeCommands();
    void sendChildrenChangedCommand(const QList<ServerNodeInstance> childList);
    void sendTokenBack();


private:
    QSet<ServerNodeInstance> m_parentChangedSet;
    QList<ServerNodeInstance> m_completedComponentList;
    QList<TokenCommand> m_tokenList;
};

} // namespace QmlDesigner

#endif // QMLDESIGNER_QT5INFORMATIONNODEINSTANCESERVER_H

==> qt-creator-2.7.2-src.tar.gz: qt-creator-2.7.2-src/share/qtcreator/qml/qmlpuppet/qml2puppet/instances/qt5informationnodeinstanceserver.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef QMLDESIGNER_QT5INFORMATIONNODEINSTANCESERVER_H
#define QMLDESIGNER_QT5INFORMATIONNODEINSTANCESERVER_H

#include "qt5nodeinstanceserver.h"
#include "tokencommand.h"

namespace QmlDesigner {

class Qt5InformationNodeInstanceServer : public Qt5NodeInstanceServer
{
    Q_OBJECT
public:
    explicit Qt5InformationNodeInstanceServer(NodeInstanceClientInterface *nodeInstanceClient);

    void reparentInstances(const ReparentInstancesCommand &command) Q_DECL_OVERRIDE;
    void clearScene(const ClearSceneCommand &command) Q_DECL_OVERRIDE;
    void createScene(const CreateSceneCommand &command) Q_DECL_OVERRIDE;
    void completeComponent(const CompleteComponentCommand &command) Q_DECL_OVERRIDE;
    void token(const TokenCommand &command) Q_DECL_OVERRIDE;
    void removeSharedMemory(const RemoveSharedMemoryCommand &command) Q_DECL_OVERRIDE;

protected:
    void collectItemChangesAndSendChangeCommands() Q_DECL_OVERRIDE;
    void sendChildrenChangedCommand(const QList<ServerNodeInstance> childList);
    void sendTokenBack();
    bool isDirtyRecursiveForNonInstanceItems(QQuickItem *item) const;

private:
    QSet<ServerNodeInstance> m_parentChangedSet;
    QList<ServerNodeInstance> m_completedComponentList;
    QList<TokenCommand> m_tokenList;
};

} // namespace QmlDesigner

#endif // QMLDESIGNER_QT5INFORMATIONNODEINSTANCESERVER_H
